@@ -1,21 +1,19 @@
 import os
 
-from django.conf import settings
+from django.conf import settings as s
 
 from django_webdriver.message import Message
 from django_webdriver.webdriver import LocalWebdriver, RemoteWebdriver
 
-SETTINGS =  settings.DJANGO_WEBDRIVER_SETTINGS
-
 
 class Environment(object):
 
     webdrivers_errors = []
 
     @staticmethod
-    def _get_capabilities(provider):
-        if(SETTINGS.get('remote_capabilities')):
-            all_capabilities = SETTINGS['remote_capabilities']
+    def _get_capabilities(provider, settings):
+        if(settings.get('remote_capabilities')):
+            all_capabilities = settings['remote_capabilities']
             capabilitie_name = provider['capabilities'] if provider.get('capabilities') else 'default'
             if(all_capabilities.get(capabilitie_name)):
                 return all_capabilities[capabilitie_name]
@@ -35,11 +33,11 @@ class Environment(object):
             exit(1)
 
     @staticmethod
-    def _get_provider():
-        providers = SETTINGS['remote_providers']
+    def _get_provider(settings):
+        providers = settings['remote_providers']
         provider_name = os.environ['DJANGO_NOSE_REMOTE']
-        if SETTINGS['remote_providers'].get(provider_name):
-            providers = SETTINGS['remote_providers']
+        if settings['remote_providers'].get(provider_name):
+            providers = settings['remote_providers']
             return providers[provider_name]
         else:
             print(Message.build_error("The name {name} is not defined in"\
@@ -88,8 +86,9 @@ class Environment(object):
 
         webdrivers = []
         if os.environ.get('DJANGO_NOSE_REMOTE'):
-            provider = cls._get_provider()
-            capabilities = cls._get_capabilities(provider)
+            settings =  s.DJANGO_WEBDRIVER_SETTINGS
+            provider = cls._get_provider(settings)
+            capabilities = cls._get_capabilities(provider, settings)
             webdrivers = cls._get_remote_drivers(capabilities)
         else:
             webdrivers = cls._get_local_drivers()
